# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCapacityInfo',
    'InstanceTag',
    'GetInstanceCapacityInfoResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class InstanceCapacityInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "totalTiB":
            suggest = "total_ti_b"
        elif key == "usedGiB":
            suggest = "used_gi_b"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceCapacityInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceCapacityInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceCapacityInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 total_ti_b: Optional[builtins.int] = None,
                 used_gi_b: Optional[builtins.int] = None):
        """
        :param builtins.int total_ti_b: 文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        :param builtins.int used_gi_b: 已使用容量（GiB）。
        """
        if total_ti_b is not None:
            pulumi.set(__self__, "total_ti_b", total_ti_b)
        if used_gi_b is not None:
            pulumi.set(__self__, "used_gi_b", used_gi_b)

    @property
    @pulumi.getter(name="totalTiB")
    def total_ti_b(self) -> Optional[builtins.int]:
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        return pulumi.get(self, "total_ti_b")

    @property
    @pulumi.getter(name="usedGiB")
    def used_gi_b(self) -> Optional[builtins.int]:
        """
        已使用容量（GiB）。
        """
        return pulumi.get(self, "used_gi_b")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceCapacityInfoResult(dict):
    def __init__(__self__, *,
                 total_ti_b: builtins.int,
                 used_gi_b: builtins.int):
        """
        :param builtins.int total_ti_b: 文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        :param builtins.int used_gi_b: 已使用容量（GiB）。
        """
        pulumi.set(__self__, "total_ti_b", total_ti_b)
        pulumi.set(__self__, "used_gi_b", used_gi_b)

    @property
    @pulumi.getter(name="totalTiB")
    def total_ti_b(self) -> builtins.int:
        """
        文件系统总容量，单位为 TiB。注意：磁盘均衡耗时会根据集群容量、集群负载等因素有所不同，如 PiB 级以上的集群扩容通常需要天级别的磁盘均衡时间，磁盘均衡完成后扩容容量才会生效（并为扩容容量计费）。
        """
        return pulumi.get(self, "total_ti_b")

    @property
    @pulumi.getter(name="usedGiB")
    def used_gi_b(self) -> builtins.int:
        """
        已使用容量（GiB）。
        """
        return pulumi.get(self, "used_gi_b")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str type: 标签类型，说明如下：Custom: 用户自定义标签。System: 系统标签。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        标签类型，说明如下：Custom: 用户自定义标签。System: 系统标签。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, auto_renew=None, billing_period=None, billing_type=None, created_time=None, description=None, eip_id=None, endpoints=None, expiration_time=None, group_limit=None, id=None, instance_id=None, message_retention=None, name=None, partition_limit=None, project_name=None, resource_tags=None, resources=None, security_group_id_lists=None, specification=None, status=None, subnet_id_lists=None, tags=None, times=None, topic_limit=None, vpc_id=None, zone_id_lists=None):
        if auto_renew and not isinstance(auto_renew, str):
            raise TypeError("Expected argument 'auto_renew' to be a str")
        pulumi.set(__self__, "auto_renew", auto_renew)
        if billing_period and not isinstance(billing_period, str):
            raise TypeError("Expected argument 'billing_period' to be a str")
        pulumi.set(__self__, "billing_period", billing_period)
        if billing_type and not isinstance(billing_type, str):
            raise TypeError("Expected argument 'billing_type' to be a str")
        pulumi.set(__self__, "billing_type", billing_type)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if eip_id and not isinstance(eip_id, str):
            raise TypeError("Expected argument 'eip_id' to be a str")
        pulumi.set(__self__, "eip_id", eip_id)
        if endpoints and not isinstance(endpoints, dict):
            raise TypeError("Expected argument 'endpoints' to be a dict")
        pulumi.set(__self__, "endpoints", endpoints)
        if expiration_time and not isinstance(expiration_time, str):
            raise TypeError("Expected argument 'expiration_time' to be a str")
        pulumi.set(__self__, "expiration_time", expiration_time)
        if group_limit and not isinstance(group_limit, int):
            raise TypeError("Expected argument 'group_limit' to be a int")
        pulumi.set(__self__, "group_limit", group_limit)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if message_retention and not isinstance(message_retention, int):
            raise TypeError("Expected argument 'message_retention' to be a int")
        pulumi.set(__self__, "message_retention", message_retention)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partition_limit and not isinstance(partition_limit, int):
            raise TypeError("Expected argument 'partition_limit' to be a int")
        pulumi.set(__self__, "partition_limit", partition_limit)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if resource_tags and not isinstance(resource_tags, list):
            raise TypeError("Expected argument 'resource_tags' to be a list")
        pulumi.set(__self__, "resource_tags", resource_tags)
        if resources and not isinstance(resources, dict):
            raise TypeError("Expected argument 'resources' to be a dict")
        pulumi.set(__self__, "resources", resources)
        if security_group_id_lists and not isinstance(security_group_id_lists, list):
            raise TypeError("Expected argument 'security_group_id_lists' to be a list")
        pulumi.set(__self__, "security_group_id_lists", security_group_id_lists)
        if specification and not isinstance(specification, str):
            raise TypeError("Expected argument 'specification' to be a str")
        pulumi.set(__self__, "specification", specification)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id_lists and not isinstance(subnet_id_lists, list):
            raise TypeError("Expected argument 'subnet_id_lists' to be a list")
        pulumi.set(__self__, "subnet_id_lists", subnet_id_lists)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if times and not isinstance(times, int):
            raise TypeError("Expected argument 'times' to be a int")
        pulumi.set(__self__, "times", times)
        if topic_limit and not isinstance(topic_limit, int):
            raise TypeError("Expected argument 'topic_limit' to be a int")
        pulumi.set(__self__, "topic_limit", topic_limit)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id_lists and not isinstance(zone_id_lists, list):
            raise TypeError("Expected argument 'zone_id_lists' to be a list")
        pulumi.set(__self__, "zone_id_lists", zone_id_lists)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> builtins.str:
        """
        是否开启自动续费，取值如下：true：开启自动续费。false：关闭自动续费。
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="billingPeriod")
    def billing_period(self) -> builtins.str:
        """
        购买时长的单位，取值如下：MONTHLY：按月购买。YEARLY：按年购买。
        """
        return pulumi.get(self, "billing_period")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.str:
        """
        实例的计费方式，取值如下：POST：按量计费。MIX：包年包月。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        实例的描述语句。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        实例是否开启公网访问。如果需要开启公网访问，请配置相同地域的公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def endpoints(self) -> 'outputs.GetInstanceEndpointsResult':
        """
        实例所有接入点响应数据。
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="expirationTime")
    def expiration_time(self) -> builtins.str:
        """
        实例过期时间。
        """
        return pulumi.get(self, "expiration_time")

    @property
    @pulumi.getter(name="groupLimit")
    def group_limit(self) -> builtins.int:
        """
        实例消费组数量上限。
        """
        return pulumi.get(self, "group_limit")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="messageRetention")
    def message_retention(self) -> builtins.int:
        """
        实例下所有 Topic 的消息保留时长，单位为小时。
        """
        return pulumi.get(self, "message_retention")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        自定设置 BMQ 实例的名称，约束限制如下：由小写字母、数字和中划线（-）组成。长度为 1~64 字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="partitionLimit")
    def partition_limit(self) -> builtins.int:
        """
        实例分区数量上限。
        """
        return pulumi.get(self, "partition_limit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceTags")
    def resource_tags(self) -> Sequence['outputs.GetInstanceResourceTagResult']:
        """
        实例资源标签列表。
        """
        return pulumi.get(self, "resource_tags")

    @property
    @pulumi.getter
    def resources(self) -> 'outputs.GetInstanceResourcesResult':
        """
        实例资源统计响应数据。
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="securityGroupIdLists")
    def security_group_id_lists(self) -> Sequence[builtins.str]:
        """
        实例使用安全组列表。
        """
        return pulumi.get(self, "security_group_id_lists")

    @property
    @pulumi.getter
    def specification(self) -> builtins.str:
        """
        实例规格。
        """
        return pulumi.get(self, "specification")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        实例的状态。取值如下：INITIALIZING：初始化中，INITIALIZATION*FAILED：初始化失败，RUNNING：运行中，MODIFYING：更新中，MODIFY*FAILED：更新失败，RELEASING：释放中，STOPPING：停止中，STOPPED：停止，RECOVERING：恢复中，EXCEPTION：异常，CAPACITY*EXPAXION*FAILED：扩容失败，EXPANDING*CAPACITY：扩容中，CANCEL*EXPANDING_CAPACITY：扩容取消中，RESTARTING：重启中，UNPAID：未支付
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIdLists")
    def subnet_id_lists(self) -> Sequence[builtins.str]:
        """
        实例使用的子网列表。
        """
        return pulumi.get(self, "subnet_id_lists")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        """
        实例资源标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def times(self) -> builtins.int:
        """
        包年包月类型实例的购买时长，单位为月。
        """
        return pulumi.get(self, "times")

    @property
    @pulumi.getter(name="topicLimit")
    def topic_limit(self) -> builtins.int:
        """
        实例Topic数量上限。
        """
        return pulumi.get(self, "topic_limit")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        实例所在VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneIdLists")
    def zone_id_lists(self) -> Sequence[builtins.str]:
        """
        实例所在可用区列表。
        """
        return pulumi.get(self, "zone_id_lists")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            auto_renew=self.auto_renew,
            billing_period=self.billing_period,
            billing_type=self.billing_type,
            created_time=self.created_time,
            description=self.description,
            eip_id=self.eip_id,
            endpoints=self.endpoints,
            expiration_time=self.expiration_time,
            group_limit=self.group_limit,
            id=self.id,
            instance_id=self.instance_id,
            message_retention=self.message_retention,
            name=self.name,
            partition_limit=self.partition_limit,
            project_name=self.project_name,
            resource_tags=self.resource_tags,
            resources=self.resources,
            security_group_id_lists=self.security_group_id_lists,
            specification=self.specification,
            status=self.status,
            subnet_id_lists=self.subnet_id_lists,
            tags=self.tags,
            times=self.times,
            topic_limit=self.topic_limit,
            vpc_id=self.vpc_id,
            zone_id_lists=self.zone_id_lists)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::BMQ::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:bmq/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        auto_renew=pulumi.get(__ret__, 'auto_renew'),
        billing_period=pulumi.get(__ret__, 'billing_period'),
        billing_type=pulumi.get(__ret__, 'billing_type'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        eip_id=pulumi.get(__ret__, 'eip_id'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        expiration_time=pulumi.get(__ret__, 'expiration_time'),
        group_limit=pulumi.get(__ret__, 'group_limit'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        message_retention=pulumi.get(__ret__, 'message_retention'),
        name=pulumi.get(__ret__, 'name'),
        partition_limit=pulumi.get(__ret__, 'partition_limit'),
        project_name=pulumi.get(__ret__, 'project_name'),
        resource_tags=pulumi.get(__ret__, 'resource_tags'),
        resources=pulumi.get(__ret__, 'resources'),
        security_group_id_lists=pulumi.get(__ret__, 'security_group_id_lists'),
        specification=pulumi.get(__ret__, 'specification'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id_lists=pulumi.get(__ret__, 'subnet_id_lists'),
        tags=pulumi.get(__ret__, 'tags'),
        times=pulumi.get(__ret__, 'times'),
        topic_limit=pulumi.get(__ret__, 'topic_limit'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_id_lists=pulumi.get(__ret__, 'zone_id_lists'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::BMQ::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:bmq/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        auto_renew=pulumi.get(__response__, 'auto_renew'),
        billing_period=pulumi.get(__response__, 'billing_period'),
        billing_type=pulumi.get(__response__, 'billing_type'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        eip_id=pulumi.get(__response__, 'eip_id'),
        endpoints=pulumi.get(__response__, 'endpoints'),
        expiration_time=pulumi.get(__response__, 'expiration_time'),
        group_limit=pulumi.get(__response__, 'group_limit'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        message_retention=pulumi.get(__response__, 'message_retention'),
        name=pulumi.get(__response__, 'name'),
        partition_limit=pulumi.get(__response__, 'partition_limit'),
        project_name=pulumi.get(__response__, 'project_name'),
        resource_tags=pulumi.get(__response__, 'resource_tags'),
        resources=pulumi.get(__response__, 'resources'),
        security_group_id_lists=pulumi.get(__response__, 'security_group_id_lists'),
        specification=pulumi.get(__response__, 'specification'),
        status=pulumi.get(__response__, 'status'),
        subnet_id_lists=pulumi.get(__response__, 'subnet_id_lists'),
        tags=pulumi.get(__response__, 'tags'),
        times=pulumi.get(__response__, 'times'),
        topic_limit=pulumi.get(__response__, 'topic_limit'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_id_lists=pulumi.get(__response__, 'zone_id_lists')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetListenerResult',
    'AwaitableGetListenerResult',
    'get_listener',
    'get_listener_output',
]

@pulumi.output_type
class GetListenerResult:
    """
    A collection of values returned by getListener.
    """
    def __init__(__self__, access_log_record_customized_headers_enabled=None, acl_ids=None, acl_status=None, acl_type=None, ca_certificate_id=None, ca_certificate_source=None, cert_center_certificate_id=None, certificate_id=None, certificate_source=None, created_time=None, customized_cfg_id=None, description=None, domain_extensions=None, enable_http2=None, enable_quic=None, enabled=None, id=None, listener_id=None, listener_name=None, load_balancer_id=None, pca_leaf_certificate_id=None, pca_root_ca_certificate_id=None, pca_sub_ca_certificate_id=None, port=None, project_name=None, protocol=None, server_group_id=None, server_groups=None, status=None, tags=None, updated_time=None):
        if access_log_record_customized_headers_enabled and not isinstance(access_log_record_customized_headers_enabled, str):
            raise TypeError("Expected argument 'access_log_record_customized_headers_enabled' to be a str")
        pulumi.set(__self__, "access_log_record_customized_headers_enabled", access_log_record_customized_headers_enabled)
        if acl_ids and not isinstance(acl_ids, list):
            raise TypeError("Expected argument 'acl_ids' to be a list")
        pulumi.set(__self__, "acl_ids", acl_ids)
        if acl_status and not isinstance(acl_status, str):
            raise TypeError("Expected argument 'acl_status' to be a str")
        pulumi.set(__self__, "acl_status", acl_status)
        if acl_type and not isinstance(acl_type, str):
            raise TypeError("Expected argument 'acl_type' to be a str")
        pulumi.set(__self__, "acl_type", acl_type)
        if ca_certificate_id and not isinstance(ca_certificate_id, str):
            raise TypeError("Expected argument 'ca_certificate_id' to be a str")
        pulumi.set(__self__, "ca_certificate_id", ca_certificate_id)
        if ca_certificate_source and not isinstance(ca_certificate_source, str):
            raise TypeError("Expected argument 'ca_certificate_source' to be a str")
        pulumi.set(__self__, "ca_certificate_source", ca_certificate_source)
        if cert_center_certificate_id and not isinstance(cert_center_certificate_id, str):
            raise TypeError("Expected argument 'cert_center_certificate_id' to be a str")
        pulumi.set(__self__, "cert_center_certificate_id", cert_center_certificate_id)
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if certificate_source and not isinstance(certificate_source, str):
            raise TypeError("Expected argument 'certificate_source' to be a str")
        pulumi.set(__self__, "certificate_source", certificate_source)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if customized_cfg_id and not isinstance(customized_cfg_id, str):
            raise TypeError("Expected argument 'customized_cfg_id' to be a str")
        pulumi.set(__self__, "customized_cfg_id", customized_cfg_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if domain_extensions and not isinstance(domain_extensions, list):
            raise TypeError("Expected argument 'domain_extensions' to be a list")
        pulumi.set(__self__, "domain_extensions", domain_extensions)
        if enable_http2 and not isinstance(enable_http2, str):
            raise TypeError("Expected argument 'enable_http2' to be a str")
        pulumi.set(__self__, "enable_http2", enable_http2)
        if enable_quic and not isinstance(enable_quic, str):
            raise TypeError("Expected argument 'enable_quic' to be a str")
        pulumi.set(__self__, "enable_quic", enable_quic)
        if enabled and not isinstance(enabled, str):
            raise TypeError("Expected argument 'enabled' to be a str")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listener_id and not isinstance(listener_id, str):
            raise TypeError("Expected argument 'listener_id' to be a str")
        pulumi.set(__self__, "listener_id", listener_id)
        if listener_name and not isinstance(listener_name, str):
            raise TypeError("Expected argument 'listener_name' to be a str")
        pulumi.set(__self__, "listener_name", listener_name)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if pca_leaf_certificate_id and not isinstance(pca_leaf_certificate_id, str):
            raise TypeError("Expected argument 'pca_leaf_certificate_id' to be a str")
        pulumi.set(__self__, "pca_leaf_certificate_id", pca_leaf_certificate_id)
        if pca_root_ca_certificate_id and not isinstance(pca_root_ca_certificate_id, str):
            raise TypeError("Expected argument 'pca_root_ca_certificate_id' to be a str")
        pulumi.set(__self__, "pca_root_ca_certificate_id", pca_root_ca_certificate_id)
        if pca_sub_ca_certificate_id and not isinstance(pca_sub_ca_certificate_id, str):
            raise TypeError("Expected argument 'pca_sub_ca_certificate_id' to be a str")
        pulumi.set(__self__, "pca_sub_ca_certificate_id", pca_sub_ca_certificate_id)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if server_group_id and not isinstance(server_group_id, str):
            raise TypeError("Expected argument 'server_group_id' to be a str")
        pulumi.set(__self__, "server_group_id", server_group_id)
        if server_groups and not isinstance(server_groups, list):
            raise TypeError("Expected argument 'server_groups' to be a list")
        pulumi.set(__self__, "server_groups", server_groups)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accessLogRecordCustomizedHeadersEnabled")
    def access_log_record_customized_headers_enabled(self) -> builtins.str:
        """
        监听器是否已开启“在访问日志中记录自定义header”的功能：on：表示该功能已开启。off：表示该功能未开启。
        """
        return pulumi.get(self, "access_log_record_customized_headers_enabled")

    @property
    @pulumi.getter(name="aclIds")
    def acl_ids(self) -> Sequence[builtins.str]:
        """
        监听器绑定的访问控制策略组 ID。当AclStatus参数配置为 on 时，AclIds为必填参数。
        """
        return pulumi.get(self, "acl_ids")

    @property
    @pulumi.getter(name="aclStatus")
    def acl_status(self) -> builtins.str:
        """
        是否开启访问控制功能。取值如下：on：开启。off ：不开启（默认）。
        """
        return pulumi.get(self, "acl_status")

    @property
    @pulumi.getter(name="aclType")
    def acl_type(self) -> builtins.str:
        """
        访问控制的方式，取值如下：white：白名单方式。表示监听器仅转发来自所选访问控制策略组中设置的IP地址或地址段的请求。 如果所选策略组中没有添加任何IP，则监听器不会转发任何请求。black：黑名单方式。表示仅拒绝来自所选访问控制策略组中设置的IP地址或地址段的请求。 如果所选策略组中没有添加任何IP，则监听器会转发全部请求。当AclStatus参数配置为 on 时，AclType为必填参数。
        """
        return pulumi.get(self, "acl_type")

    @property
    @pulumi.getter(name="caCertificateId")
    def ca_certificate_id(self) -> builtins.str:
        """
        HTTPS 监听器关联的 CA 证书 ID。该参数用于 HTTPS 监听器的双向认证。当证书来源是 alb 时，必须指定 CACertificateId 参数。
        """
        return pulumi.get(self, "ca_certificate_id")

    @property
    @pulumi.getter(name="caCertificateSource")
    def ca_certificate_source(self) -> builtins.str:
        """
        HTTPS 监听器关联的 CA 证书的来源，用于双向认证。alb（默认）：表示通过 ALB 上传的证书。标准版 ALB 实例不支持此来源的证书。pca*root：表示通过火山引擎证书中心购买或上传的私有根 CA 证书。pca*sub：表示通过火山引擎证书中心购买或上传的私有子 CA 证书。
        """
        return pulumi.get(self, "ca_certificate_source")

    @property
    @pulumi.getter(name="certCenterCertificateId")
    def cert_center_certificate_id(self) -> builtins.str:
        """
        HTTPS监听器关联的证书 ID。创建 HTTPS 监听器且证书来源为 cert_center 时必传。
        """
        return pulumi.get(self, "cert_center_certificate_id")

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> builtins.str:
        """
        HTTPS监听器关联的证书 ID。创建 HTTPS 监听器且证书来源为 alb 时必传。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter(name="certificateSource")
    def certificate_source(self) -> builtins.str:
        """
        HTTPS监听器关联的默认证书的来源，取值：alb：表示通过 ALB 上传的证书。cert*center：表示通过火山引擎证书中心购买或上传的 SSL 证书。pca*leaf：表示通过火山引擎证书中心购买或上传的私有叶子证书。
        """
        return pulumi.get(self, "certificate_source")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        监听器的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> builtins.str:
        """
        个性化配置ID，未绑定时值为空字符串。
        """
        return pulumi.get(self, "customized_cfg_id")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        监听器的描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="domainExtensions")
    def domain_extensions(self) -> Sequence['outputs.GetListenerDomainExtensionResult']:
        """
        HTTPS监听器关联的扩展域名列表。一个HTTPS监听器能关联的扩展域名上限为20个。
        """
        return pulumi.get(self, "domain_extensions")

    @property
    @pulumi.getter(name="enableHttp2")
    def enable_http2(self) -> builtins.str:
        """
        HTTP2.0 特性开关，该参数仅对 HTTPS 监听器有效。取值如下：on：开启。off：关闭（默认）。
        """
        return pulumi.get(self, "enable_http2")

    @property
    @pulumi.getter(name="enableQuic")
    def enable_quic(self) -> builtins.str:
        """
        QUIC 特性开关，该参数仅对 HTTPS 监听器有效，取值如下：on：开启。off：关闭（默认）。只有标准版 ALB 实例支持 QUIC。
        """
        return pulumi.get(self, "enable_quic")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.str:
        """
        监听器开启/关闭，取值如下：on：开启（默认）。off：关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> builtins.str:
        """
        监听器 ID。
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="listenerName")
    def listener_name(self) -> builtins.str:
        """
        监听器的名字。不填写时以“协议-端口”格式命名。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点（.）、下划线（_）和短横线（-）。长度限制在1-128字符之间。
        """
        return pulumi.get(self, "listener_name")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        监听器所属的负载均衡实例 ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="pcaLeafCertificateId")
    def pca_leaf_certificate_id(self) -> builtins.str:
        """
        HTTPS监听器关联的私有叶子证书 ID。创建 HTTPS 监听器且证书来源为 pca_leaf 时必传。
        """
        return pulumi.get(self, "pca_leaf_certificate_id")

    @property
    @pulumi.getter(name="pcaRootCaCertificateId")
    def pca_root_ca_certificate_id(self) -> builtins.str:
        """
        HTTPS 监听器关联的 CA 证书 ID。该参数用于 HTTPS 监听器的双向认证。当证书来源是 pca_root 时，必须指定 PcaRootCACertificateId 参数。
        """
        return pulumi.get(self, "pca_root_ca_certificate_id")

    @property
    @pulumi.getter(name="pcaSubCaCertificateId")
    def pca_sub_ca_certificate_id(self) -> builtins.str:
        """
        HTTPS 监听器关联的 CA 证书 ID。该参数用于 HTTPS 监听器的双向认证。当证书来源是 pca_sub 时，必须指定 PcaSubCACertificateId 参数。
        """
        return pulumi.get(self, "pca_sub_ca_certificate_id")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        监听器的监听端口，取值：1   - 65535 。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        监听器所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        监听器的协议，支持 HTTP 协议和 HTTPS 协议。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        监听器的默认服务器组。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="serverGroups")
    def server_groups(self) -> Sequence['outputs.GetListenerServerGroupResult']:
        """
        关联监听器的所有服务器组。
        """
        return pulumi.get(self, "server_groups")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        监听器的状态。取值如下：Creating：创建中。Active： 运行中。Pending： 变配中。Disabled：已停止。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetListenerTagResult']:
        """
        监听器所属标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        监听器最近一次的操作时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetListenerResult(GetListenerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetListenerResult(
            access_log_record_customized_headers_enabled=self.access_log_record_customized_headers_enabled,
            acl_ids=self.acl_ids,
            acl_status=self.acl_status,
            acl_type=self.acl_type,
            ca_certificate_id=self.ca_certificate_id,
            ca_certificate_source=self.ca_certificate_source,
            cert_center_certificate_id=self.cert_center_certificate_id,
            certificate_id=self.certificate_id,
            certificate_source=self.certificate_source,
            created_time=self.created_time,
            customized_cfg_id=self.customized_cfg_id,
            description=self.description,
            domain_extensions=self.domain_extensions,
            enable_http2=self.enable_http2,
            enable_quic=self.enable_quic,
            enabled=self.enabled,
            id=self.id,
            listener_id=self.listener_id,
            listener_name=self.listener_name,
            load_balancer_id=self.load_balancer_id,
            pca_leaf_certificate_id=self.pca_leaf_certificate_id,
            pca_root_ca_certificate_id=self.pca_root_ca_certificate_id,
            pca_sub_ca_certificate_id=self.pca_sub_ca_certificate_id,
            port=self.port,
            project_name=self.project_name,
            protocol=self.protocol,
            server_group_id=self.server_group_id,
            server_groups=self.server_groups,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_listener(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetListenerResult:
    """
    Data Source schema for Byteplus::ALB::Listener


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:alb/getListener:getListener', __args__, opts=opts, typ=GetListenerResult).value

    return AwaitableGetListenerResult(
        access_log_record_customized_headers_enabled=pulumi.get(__ret__, 'access_log_record_customized_headers_enabled'),
        acl_ids=pulumi.get(__ret__, 'acl_ids'),
        acl_status=pulumi.get(__ret__, 'acl_status'),
        acl_type=pulumi.get(__ret__, 'acl_type'),
        ca_certificate_id=pulumi.get(__ret__, 'ca_certificate_id'),
        ca_certificate_source=pulumi.get(__ret__, 'ca_certificate_source'),
        cert_center_certificate_id=pulumi.get(__ret__, 'cert_center_certificate_id'),
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        certificate_source=pulumi.get(__ret__, 'certificate_source'),
        created_time=pulumi.get(__ret__, 'created_time'),
        customized_cfg_id=pulumi.get(__ret__, 'customized_cfg_id'),
        description=pulumi.get(__ret__, 'description'),
        domain_extensions=pulumi.get(__ret__, 'domain_extensions'),
        enable_http2=pulumi.get(__ret__, 'enable_http2'),
        enable_quic=pulumi.get(__ret__, 'enable_quic'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        listener_id=pulumi.get(__ret__, 'listener_id'),
        listener_name=pulumi.get(__ret__, 'listener_name'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        pca_leaf_certificate_id=pulumi.get(__ret__, 'pca_leaf_certificate_id'),
        pca_root_ca_certificate_id=pulumi.get(__ret__, 'pca_root_ca_certificate_id'),
        pca_sub_ca_certificate_id=pulumi.get(__ret__, 'pca_sub_ca_certificate_id'),
        port=pulumi.get(__ret__, 'port'),
        project_name=pulumi.get(__ret__, 'project_name'),
        protocol=pulumi.get(__ret__, 'protocol'),
        server_group_id=pulumi.get(__ret__, 'server_group_id'),
        server_groups=pulumi.get(__ret__, 'server_groups'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_listener_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetListenerResult]:
    """
    Data Source schema for Byteplus::ALB::Listener


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:alb/getListener:getListener', __args__, opts=opts, typ=GetListenerResult)
    return __ret__.apply(lambda __response__: GetListenerResult(
        access_log_record_customized_headers_enabled=pulumi.get(__response__, 'access_log_record_customized_headers_enabled'),
        acl_ids=pulumi.get(__response__, 'acl_ids'),
        acl_status=pulumi.get(__response__, 'acl_status'),
        acl_type=pulumi.get(__response__, 'acl_type'),
        ca_certificate_id=pulumi.get(__response__, 'ca_certificate_id'),
        ca_certificate_source=pulumi.get(__response__, 'ca_certificate_source'),
        cert_center_certificate_id=pulumi.get(__response__, 'cert_center_certificate_id'),
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        certificate_source=pulumi.get(__response__, 'certificate_source'),
        created_time=pulumi.get(__response__, 'created_time'),
        customized_cfg_id=pulumi.get(__response__, 'customized_cfg_id'),
        description=pulumi.get(__response__, 'description'),
        domain_extensions=pulumi.get(__response__, 'domain_extensions'),
        enable_http2=pulumi.get(__response__, 'enable_http2'),
        enable_quic=pulumi.get(__response__, 'enable_quic'),
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        listener_id=pulumi.get(__response__, 'listener_id'),
        listener_name=pulumi.get(__response__, 'listener_name'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        pca_leaf_certificate_id=pulumi.get(__response__, 'pca_leaf_certificate_id'),
        pca_root_ca_certificate_id=pulumi.get(__response__, 'pca_root_ca_certificate_id'),
        pca_sub_ca_certificate_id=pulumi.get(__response__, 'pca_sub_ca_certificate_id'),
        port=pulumi.get(__response__, 'port'),
        project_name=pulumi.get(__response__, 'project_name'),
        protocol=pulumi.get(__response__, 'protocol'),
        server_group_id=pulumi.get(__response__, 'server_group_id'),
        server_groups=pulumi.get(__response__, 'server_groups'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTopicResult',
    'AwaitableGetTopicResult',
    'get_topic',
    'get_topic_output',
]

@pulumi.output_type
class GetTopicResult:
    """
    A collection of values returned by getTopic.
    """
    def __init__(__self__, access_policies=None, all_authority=None, cleanup_policies=None, created_time=None, description=None, id=None, instance_id=None, log_retention_hours=None, parameters=None, partition_number=None, replica_number=None, status=None, tags=None, topic_name=None, used_storage_percentage_in_instance=None, used_storage_space_in_bytes=None):
        if access_policies and not isinstance(access_policies, list):
            raise TypeError("Expected argument 'access_policies' to be a list")
        pulumi.set(__self__, "access_policies", access_policies)
        if all_authority and not isinstance(all_authority, bool):
            raise TypeError("Expected argument 'all_authority' to be a bool")
        pulumi.set(__self__, "all_authority", all_authority)
        if cleanup_policies and not isinstance(cleanup_policies, list):
            raise TypeError("Expected argument 'cleanup_policies' to be a list")
        pulumi.set(__self__, "cleanup_policies", cleanup_policies)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if log_retention_hours and not isinstance(log_retention_hours, int):
            raise TypeError("Expected argument 'log_retention_hours' to be a int")
        pulumi.set(__self__, "log_retention_hours", log_retention_hours)
        if parameters and not isinstance(parameters, str):
            raise TypeError("Expected argument 'parameters' to be a str")
        pulumi.set(__self__, "parameters", parameters)
        if partition_number and not isinstance(partition_number, int):
            raise TypeError("Expected argument 'partition_number' to be a int")
        pulumi.set(__self__, "partition_number", partition_number)
        if replica_number and not isinstance(replica_number, int):
            raise TypeError("Expected argument 'replica_number' to be a int")
        pulumi.set(__self__, "replica_number", replica_number)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if topic_name and not isinstance(topic_name, str):
            raise TypeError("Expected argument 'topic_name' to be a str")
        pulumi.set(__self__, "topic_name", topic_name)
        if used_storage_percentage_in_instance and not isinstance(used_storage_percentage_in_instance, float):
            raise TypeError("Expected argument 'used_storage_percentage_in_instance' to be a float")
        pulumi.set(__self__, "used_storage_percentage_in_instance", used_storage_percentage_in_instance)
        if used_storage_space_in_bytes and not isinstance(used_storage_space_in_bytes, int):
            raise TypeError("Expected argument 'used_storage_space_in_bytes' to be a int")
        pulumi.set(__self__, "used_storage_space_in_bytes", used_storage_space_in_bytes)

    @property
    @pulumi.getter(name="accessPolicies")
    def access_policies(self) -> Sequence['outputs.GetTopicAccessPolicyResult']:
        """
        自定义权限配置，即为某些用户设置对于此 Topic 的自定义权限。仅在 AllAuthority 为 False 时需要设置。
        """
        return pulumi.get(self, "access_policies")

    @property
    @pulumi.getter(name="allAuthority")
    def all_authority(self) -> builtins.bool:
        """
        待创建的Topic默认是否对所有用户都开启读写权限。true：（默认）所有用户都具备此 Topic 的读写权限。false：并非所有用户都具备此 Topic 的读写权限。默认情况下，用户对于此 Topic 的权限沿用用户的默认权限，如果默认权限不满足需求，您也可以通过 AccessPolicies 指定某个用户对于此 Topic 的自定义权限。
        """
        return pulumi.get(self, "all_authority")

    @property
    @pulumi.getter(name="cleanupPolicies")
    def cleanup_policies(self) -> Sequence[builtins.str]:
        """
        Topic 的消息清理策略，支持以下三种取值方式：[delete]：默认的消息清理策略。在磁盘容量充足的情况下，保留在最长保留时间范围内的消息；在磁盘容量不足时，将提前删除旧消息，以保证服务可用性。[compact]：COMPACT 消息清理策略针对每个消息的 Key 进行整合，对于有相同 Key 的消息，只保留最新的 value 值，旧的记录则会被清除。[delete,compact]：同时配置 DELETE 和 COMPACT 两种消息清理策略。只要消息满足任一条清理策略时，都将被清除。
        """
        return pulumi.get(self, "cleanup_policies")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        Topic 的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Topic 的描述信息。长度不超过 128 个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="logRetentionHours")
    def log_retention_hours(self) -> builtins.int:
        """
        消息保留时长，单位小时。Topic维度的消息保留时长，取值范围：1   - 2160小时（90天）。
        """
        return pulumi.get(self, "log_retention_hours")

    @property
    @pulumi.getter
    def parameters(self) -> builtins.str:
        """
        Topic 级别的参数配置。Parameters 参数说明 MinInsyncReplicaNumber:2：最小同步副本个数。当同步副本个数小于配置值时，消息将无法写入对应 Topic。配置值越大，数据可靠性增加，但是可用性将会降低。默认值为副本数减 1。考虑到 Topic 的可用性，建议设置为副本数减 1。MessageMaxByte:12：最大消息大小。单位为 MB，取值范围为 1～12。默认沿用实例的最大消息大小设置。LogRetentionHours:72：消息保留时长。单位为小时，取值范围为 0～2160，即消息最久保留 90 天。默认沿用实例的消息保留时长设置。
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> builtins.int:
        """
        Topic 分区数。取值范围为 1~300，如果实例中已创建了其他 Topic，则所有 Topic 的分区数之和不超过该实例的分区数上限。如果分区数无法满足业务需求，您可以购买更多分区，提升实例的分区数量上限。
        """
        return pulumi.get(self, "partition_number")

    @property
    @pulumi.getter(name="replicaNumber")
    def replica_number(self) -> builtins.int:
        """
        Topic 副本个数。可设置为为 2 或 3，默认值为 3。
        """
        return pulumi.get(self, "replica_number")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Topic 的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTopicTagResult']:
        """
        Topic 的标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> builtins.str:
        """
        待创建的 Topic 名称。3～64 个字符。必须以英文或数字开头。支持的字符包括英文、数字、连字符（-）、下划线（_）和英文句号（.）。
        """
        return pulumi.get(self, "topic_name")

    @property
    @pulumi.getter(name="usedStoragePercentageInInstance")
    def used_storage_percentage_in_instance(self) -> builtins.float:
        """
        当前 Topic 总数据量占实例总存储空间的比例，控制台页面显示为保留两位小数的百分数。
        """
        return pulumi.get(self, "used_storage_percentage_in_instance")

    @property
    @pulumi.getter(name="usedStorageSpaceInBytes")
    def used_storage_space_in_bytes(self) -> builtins.int:
        """
        当前 Topic 已使用的总存储空间大小。
        """
        return pulumi.get(self, "used_storage_space_in_bytes")


class AwaitableGetTopicResult(GetTopicResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTopicResult(
            access_policies=self.access_policies,
            all_authority=self.all_authority,
            cleanup_policies=self.cleanup_policies,
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            instance_id=self.instance_id,
            log_retention_hours=self.log_retention_hours,
            parameters=self.parameters,
            partition_number=self.partition_number,
            replica_number=self.replica_number,
            status=self.status,
            tags=self.tags,
            topic_name=self.topic_name,
            used_storage_percentage_in_instance=self.used_storage_percentage_in_instance,
            used_storage_space_in_bytes=self.used_storage_space_in_bytes)


def get_topic(id: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTopicResult:
    """
    Data Source schema for Byteplus::Kafka::Topic


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:kafka/getTopic:getTopic', __args__, opts=opts, typ=GetTopicResult).value

    return AwaitableGetTopicResult(
        access_policies=pulumi.get(__ret__, 'access_policies'),
        all_authority=pulumi.get(__ret__, 'all_authority'),
        cleanup_policies=pulumi.get(__ret__, 'cleanup_policies'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        log_retention_hours=pulumi.get(__ret__, 'log_retention_hours'),
        parameters=pulumi.get(__ret__, 'parameters'),
        partition_number=pulumi.get(__ret__, 'partition_number'),
        replica_number=pulumi.get(__ret__, 'replica_number'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        topic_name=pulumi.get(__ret__, 'topic_name'),
        used_storage_percentage_in_instance=pulumi.get(__ret__, 'used_storage_percentage_in_instance'),
        used_storage_space_in_bytes=pulumi.get(__ret__, 'used_storage_space_in_bytes'))
def get_topic_output(id: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTopicResult]:
    """
    Data Source schema for Byteplus::Kafka::Topic


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:kafka/getTopic:getTopic', __args__, opts=opts, typ=GetTopicResult)
    return __ret__.apply(lambda __response__: GetTopicResult(
        access_policies=pulumi.get(__response__, 'access_policies'),
        all_authority=pulumi.get(__response__, 'all_authority'),
        cleanup_policies=pulumi.get(__response__, 'cleanup_policies'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        log_retention_hours=pulumi.get(__response__, 'log_retention_hours'),
        parameters=pulumi.get(__response__, 'parameters'),
        partition_number=pulumi.get(__response__, 'partition_number'),
        replica_number=pulumi.get(__response__, 'replica_number'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        topic_name=pulumi.get(__response__, 'topic_name'),
        used_storage_percentage_in_instance=pulumi.get(__response__, 'used_storage_percentage_in_instance'),
        used_storage_space_in_bytes=pulumi.get(__response__, 'used_storage_space_in_bytes')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, affinity_group_size=None, auto_renew=None, auto_renew_period=None, cpu_max_frequency=None, cpu_memory=None, created_at=None, credit_specification=None, deletion_protection=None, deployment_set_group_number=None, deployment_set_id=None, description=None, eip_address=None, expired_at=None, hostname=None, hpc_cluster_id=None, id=None, image=None, instance_charge_type=None, instance_id=None, instance_name=None, instance_type=None, key_pair=None, operation_system=None, password=None, period=None, period_unit=None, placement=None, primary_network_interface=None, project_name=None, secondary_network_interfaces=None, spot_price_limit=None, spot_strategy=None, status=None, stopped_mode=None, system_volume=None, tags=None, updated_at=None, user_data=None, vpc_id=None, zone_id=None):
        if affinity_group_size and not isinstance(affinity_group_size, int):
            raise TypeError("Expected argument 'affinity_group_size' to be a int")
        pulumi.set(__self__, "affinity_group_size", affinity_group_size)
        if auto_renew and not isinstance(auto_renew, bool):
            raise TypeError("Expected argument 'auto_renew' to be a bool")
        pulumi.set(__self__, "auto_renew", auto_renew)
        if auto_renew_period and not isinstance(auto_renew_period, int):
            raise TypeError("Expected argument 'auto_renew_period' to be a int")
        pulumi.set(__self__, "auto_renew_period", auto_renew_period)
        if cpu_max_frequency and not isinstance(cpu_max_frequency, float):
            raise TypeError("Expected argument 'cpu_max_frequency' to be a float")
        pulumi.set(__self__, "cpu_max_frequency", cpu_max_frequency)
        if cpu_memory and not isinstance(cpu_memory, dict):
            raise TypeError("Expected argument 'cpu_memory' to be a dict")
        pulumi.set(__self__, "cpu_memory", cpu_memory)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if credit_specification and not isinstance(credit_specification, str):
            raise TypeError("Expected argument 'credit_specification' to be a str")
        pulumi.set(__self__, "credit_specification", credit_specification)
        if deletion_protection and not isinstance(deletion_protection, bool):
            raise TypeError("Expected argument 'deletion_protection' to be a bool")
        pulumi.set(__self__, "deletion_protection", deletion_protection)
        if deployment_set_group_number and not isinstance(deployment_set_group_number, int):
            raise TypeError("Expected argument 'deployment_set_group_number' to be a int")
        pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id and not isinstance(deployment_set_id, str):
            raise TypeError("Expected argument 'deployment_set_id' to be a str")
        pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if eip_address and not isinstance(eip_address, dict):
            raise TypeError("Expected argument 'eip_address' to be a dict")
        pulumi.set(__self__, "eip_address", eip_address)
        if expired_at and not isinstance(expired_at, str):
            raise TypeError("Expected argument 'expired_at' to be a str")
        pulumi.set(__self__, "expired_at", expired_at)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if hpc_cluster_id and not isinstance(hpc_cluster_id, str):
            raise TypeError("Expected argument 'hpc_cluster_id' to be a str")
        pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image and not isinstance(image, dict):
            raise TypeError("Expected argument 'image' to be a dict")
        pulumi.set(__self__, "image", image)
        if instance_charge_type and not isinstance(instance_charge_type, str):
            raise TypeError("Expected argument 'instance_charge_type' to be a str")
        pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if key_pair and not isinstance(key_pair, dict):
            raise TypeError("Expected argument 'key_pair' to be a dict")
        pulumi.set(__self__, "key_pair", key_pair)
        if operation_system and not isinstance(operation_system, dict):
            raise TypeError("Expected argument 'operation_system' to be a dict")
        pulumi.set(__self__, "operation_system", operation_system)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if period and not isinstance(period, int):
            raise TypeError("Expected argument 'period' to be a int")
        pulumi.set(__self__, "period", period)
        if period_unit and not isinstance(period_unit, str):
            raise TypeError("Expected argument 'period_unit' to be a str")
        pulumi.set(__self__, "period_unit", period_unit)
        if placement and not isinstance(placement, dict):
            raise TypeError("Expected argument 'placement' to be a dict")
        pulumi.set(__self__, "placement", placement)
        if primary_network_interface and not isinstance(primary_network_interface, dict):
            raise TypeError("Expected argument 'primary_network_interface' to be a dict")
        pulumi.set(__self__, "primary_network_interface", primary_network_interface)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if secondary_network_interfaces and not isinstance(secondary_network_interfaces, list):
            raise TypeError("Expected argument 'secondary_network_interfaces' to be a list")
        pulumi.set(__self__, "secondary_network_interfaces", secondary_network_interfaces)
        if spot_price_limit and not isinstance(spot_price_limit, float):
            raise TypeError("Expected argument 'spot_price_limit' to be a float")
        pulumi.set(__self__, "spot_price_limit", spot_price_limit)
        if spot_strategy and not isinstance(spot_strategy, str):
            raise TypeError("Expected argument 'spot_strategy' to be a str")
        pulumi.set(__self__, "spot_strategy", spot_strategy)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if stopped_mode and not isinstance(stopped_mode, str):
            raise TypeError("Expected argument 'stopped_mode' to be a str")
        pulumi.set(__self__, "stopped_mode", stopped_mode)
        if system_volume and not isinstance(system_volume, dict):
            raise TypeError("Expected argument 'system_volume' to be a dict")
        pulumi.set(__self__, "system_volume", system_volume)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if user_data and not isinstance(user_data, str):
            raise TypeError("Expected argument 'user_data' to be a str")
        pulumi.set(__self__, "user_data", user_data)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="affinityGroupSize")
    def affinity_group_size(self) -> builtins.int:
        return pulumi.get(self, "affinity_group_size")

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> builtins.bool:
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="autoRenewPeriod")
    def auto_renew_period(self) -> builtins.int:
        return pulumi.get(self, "auto_renew_period")

    @property
    @pulumi.getter(name="cpuMaxFrequency")
    def cpu_max_frequency(self) -> builtins.float:
        return pulumi.get(self, "cpu_max_frequency")

    @property
    @pulumi.getter(name="cpuMemory")
    def cpu_memory(self) -> 'outputs.GetInstanceCpuMemoryResult':
        return pulumi.get(self, "cpu_memory")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="creditSpecification")
    def credit_specification(self) -> builtins.str:
        return pulumi.get(self, "credit_specification")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> builtins.bool:
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> builtins.int:
        return pulumi.get(self, "deployment_set_group_number")

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> builtins.str:
        return pulumi.get(self, "deployment_set_id")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> 'outputs.GetInstanceEipAddressResult':
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> builtins.str:
        return pulumi.get(self, "expired_at")

    @property
    @pulumi.getter
    def hostname(self) -> builtins.str:
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> builtins.str:
        return pulumi.get(self, "hpc_cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def image(self) -> 'outputs.GetInstanceImageResult':
        return pulumi.get(self, "image")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> builtins.str:
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="keyPair")
    def key_pair(self) -> 'outputs.GetInstanceKeyPairResult':
        return pulumi.get(self, "key_pair")

    @property
    @pulumi.getter(name="operationSystem")
    def operation_system(self) -> 'outputs.GetInstanceOperationSystemResult':
        return pulumi.get(self, "operation_system")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def period(self) -> builtins.int:
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> builtins.str:
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter
    def placement(self) -> 'outputs.GetInstancePlacementResult':
        return pulumi.get(self, "placement")

    @property
    @pulumi.getter(name="primaryNetworkInterface")
    def primary_network_interface(self) -> 'outputs.GetInstancePrimaryNetworkInterfaceResult':
        return pulumi.get(self, "primary_network_interface")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="secondaryNetworkInterfaces")
    def secondary_network_interfaces(self) -> Sequence['outputs.GetInstanceSecondaryNetworkInterfaceResult']:
        return pulumi.get(self, "secondary_network_interfaces")

    @property
    @pulumi.getter(name="spotPriceLimit")
    def spot_price_limit(self) -> builtins.float:
        return pulumi.get(self, "spot_price_limit")

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> builtins.str:
        return pulumi.get(self, "spot_strategy")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="stoppedMode")
    def stopped_mode(self) -> builtins.str:
        return pulumi.get(self, "stopped_mode")

    @property
    @pulumi.getter(name="systemVolume")
    def system_volume(self) -> 'outputs.GetInstanceSystemVolumeResult':
        return pulumi.get(self, "system_volume")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> builtins.str:
        return pulumi.get(self, "user_data")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        return pulumi.get(self, "zone_id")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            affinity_group_size=self.affinity_group_size,
            auto_renew=self.auto_renew,
            auto_renew_period=self.auto_renew_period,
            cpu_max_frequency=self.cpu_max_frequency,
            cpu_memory=self.cpu_memory,
            created_at=self.created_at,
            credit_specification=self.credit_specification,
            deletion_protection=self.deletion_protection,
            deployment_set_group_number=self.deployment_set_group_number,
            deployment_set_id=self.deployment_set_id,
            description=self.description,
            eip_address=self.eip_address,
            expired_at=self.expired_at,
            hostname=self.hostname,
            hpc_cluster_id=self.hpc_cluster_id,
            id=self.id,
            image=self.image,
            instance_charge_type=self.instance_charge_type,
            instance_id=self.instance_id,
            instance_name=self.instance_name,
            instance_type=self.instance_type,
            key_pair=self.key_pair,
            operation_system=self.operation_system,
            password=self.password,
            period=self.period,
            period_unit=self.period_unit,
            placement=self.placement,
            primary_network_interface=self.primary_network_interface,
            project_name=self.project_name,
            secondary_network_interfaces=self.secondary_network_interfaces,
            spot_price_limit=self.spot_price_limit,
            spot_strategy=self.spot_strategy,
            status=self.status,
            stopped_mode=self.stopped_mode,
            system_volume=self.system_volume,
            tags=self.tags,
            updated_at=self.updated_at,
            user_data=self.user_data,
            vpc_id=self.vpc_id,
            zone_id=self.zone_id)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::ECS::Instance
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        affinity_group_size=pulumi.get(__ret__, 'affinity_group_size'),
        auto_renew=pulumi.get(__ret__, 'auto_renew'),
        auto_renew_period=pulumi.get(__ret__, 'auto_renew_period'),
        cpu_max_frequency=pulumi.get(__ret__, 'cpu_max_frequency'),
        cpu_memory=pulumi.get(__ret__, 'cpu_memory'),
        created_at=pulumi.get(__ret__, 'created_at'),
        credit_specification=pulumi.get(__ret__, 'credit_specification'),
        deletion_protection=pulumi.get(__ret__, 'deletion_protection'),
        deployment_set_group_number=pulumi.get(__ret__, 'deployment_set_group_number'),
        deployment_set_id=pulumi.get(__ret__, 'deployment_set_id'),
        description=pulumi.get(__ret__, 'description'),
        eip_address=pulumi.get(__ret__, 'eip_address'),
        expired_at=pulumi.get(__ret__, 'expired_at'),
        hostname=pulumi.get(__ret__, 'hostname'),
        hpc_cluster_id=pulumi.get(__ret__, 'hpc_cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        image=pulumi.get(__ret__, 'image'),
        instance_charge_type=pulumi.get(__ret__, 'instance_charge_type'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        key_pair=pulumi.get(__ret__, 'key_pair'),
        operation_system=pulumi.get(__ret__, 'operation_system'),
        password=pulumi.get(__ret__, 'password'),
        period=pulumi.get(__ret__, 'period'),
        period_unit=pulumi.get(__ret__, 'period_unit'),
        placement=pulumi.get(__ret__, 'placement'),
        primary_network_interface=pulumi.get(__ret__, 'primary_network_interface'),
        project_name=pulumi.get(__ret__, 'project_name'),
        secondary_network_interfaces=pulumi.get(__ret__, 'secondary_network_interfaces'),
        spot_price_limit=pulumi.get(__ret__, 'spot_price_limit'),
        spot_strategy=pulumi.get(__ret__, 'spot_strategy'),
        status=pulumi.get(__ret__, 'status'),
        stopped_mode=pulumi.get(__ret__, 'stopped_mode'),
        system_volume=pulumi.get(__ret__, 'system_volume'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        user_data=pulumi.get(__ret__, 'user_data'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::ECS::Instance
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        affinity_group_size=pulumi.get(__response__, 'affinity_group_size'),
        auto_renew=pulumi.get(__response__, 'auto_renew'),
        auto_renew_period=pulumi.get(__response__, 'auto_renew_period'),
        cpu_max_frequency=pulumi.get(__response__, 'cpu_max_frequency'),
        cpu_memory=pulumi.get(__response__, 'cpu_memory'),
        created_at=pulumi.get(__response__, 'created_at'),
        credit_specification=pulumi.get(__response__, 'credit_specification'),
        deletion_protection=pulumi.get(__response__, 'deletion_protection'),
        deployment_set_group_number=pulumi.get(__response__, 'deployment_set_group_number'),
        deployment_set_id=pulumi.get(__response__, 'deployment_set_id'),
        description=pulumi.get(__response__, 'description'),
        eip_address=pulumi.get(__response__, 'eip_address'),
        expired_at=pulumi.get(__response__, 'expired_at'),
        hostname=pulumi.get(__response__, 'hostname'),
        hpc_cluster_id=pulumi.get(__response__, 'hpc_cluster_id'),
        id=pulumi.get(__response__, 'id'),
        image=pulumi.get(__response__, 'image'),
        instance_charge_type=pulumi.get(__response__, 'instance_charge_type'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        key_pair=pulumi.get(__response__, 'key_pair'),
        operation_system=pulumi.get(__response__, 'operation_system'),
        password=pulumi.get(__response__, 'password'),
        period=pulumi.get(__response__, 'period'),
        period_unit=pulumi.get(__response__, 'period_unit'),
        placement=pulumi.get(__response__, 'placement'),
        primary_network_interface=pulumi.get(__response__, 'primary_network_interface'),
        project_name=pulumi.get(__response__, 'project_name'),
        secondary_network_interfaces=pulumi.get(__response__, 'secondary_network_interfaces'),
        spot_price_limit=pulumi.get(__response__, 'spot_price_limit'),
        spot_strategy=pulumi.get(__response__, 'spot_strategy'),
        status=pulumi.get(__response__, 'status'),
        stopped_mode=pulumi.get(__response__, 'stopped_mode'),
        system_volume=pulumi.get(__response__, 'system_volume'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        user_data=pulumi.get(__response__, 'user_data'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecurityGroupArgs', 'SecurityGroup']

@pulumi.input_type
class SecurityGroupArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupEgressPermissionArgs']]]] = None,
                 ingress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupIngressPermissionArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupTagArgs']]]] = None):
        """
        The set of arguments for constructing a SecurityGroup resource.
        :param pulumi.Input[builtins.str] vpc_id: 安全组所属的VPC ID。
        :param pulumi.Input[builtins.str] description: 安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        :param pulumi.Input[builtins.str] project_name: 安全组所属项目名称。不填默认项目为default。
        :param pulumi.Input[builtins.str] security_group_name: 安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if egress_permissions is not None:
            pulumi.set(__self__, "egress_permissions", egress_permissions)
        if ingress_permissions is not None:
            pulumi.set(__self__, "ingress_permissions", ingress_permissions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_group_name is not None:
            pulumi.set(__self__, "security_group_name", security_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        安全组所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="egressPermissions")
    def egress_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupEgressPermissionArgs']]]]:
        return pulumi.get(self, "egress_permissions")

    @egress_permissions.setter
    def egress_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupEgressPermissionArgs']]]]):
        pulumi.set(self, "egress_permissions", value)

    @property
    @pulumi.getter(name="ingressPermissions")
    def ingress_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupIngressPermissionArgs']]]]:
        return pulumi.get(self, "ingress_permissions")

    @ingress_permissions.setter
    def ingress_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupIngressPermissionArgs']]]]):
        pulumi.set(self, "ingress_permissions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组所属项目名称。不填默认项目为default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        """
        return pulumi.get(self, "security_group_name")

    @security_group_name.setter
    def security_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_group_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SecurityGroupState:
    def __init__(__self__, *,
                 creation_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupEgressPermissionArgs']]]] = None,
                 ingress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupIngressPermissionArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_managed: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering SecurityGroup resources.
        :param pulumi.Input[builtins.str] creation_time: 安全组创建时间。
        :param pulumi.Input[builtins.str] description: 安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        :param pulumi.Input[builtins.str] project_name: 安全组所属项目名称。不填默认项目为default。
        :param pulumi.Input[builtins.str] security_group_id: 安全组ID。
        :param pulumi.Input[builtins.str] security_group_name: 安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        :param pulumi.Input[builtins.bool] service_managed: 安全组是否为托管安全组。true为托管安全组，false为非托管安全组。
        :param pulumi.Input[builtins.str] status: 安全组状态。Available为可用，Creating为创建中。
        :param pulumi.Input[builtins.str] type: 安全组类型。1、default：默认安全组。2、normal：自定义安全组。3、VpnGW： VPN网关安全组。4、NatGW： Nat网关安全组。 5、cidr_only：CIDR-Only安全组。
        :param pulumi.Input[builtins.str] vpc_id: 安全组所属的VPC ID。
        """
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if egress_permissions is not None:
            pulumi.set(__self__, "egress_permissions", egress_permissions)
        if ingress_permissions is not None:
            pulumi.set(__self__, "ingress_permissions", ingress_permissions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if security_group_name is not None:
            pulumi.set(__self__, "security_group_name", security_group_name)
        if service_managed is not None:
            pulumi.set(__self__, "service_managed", service_managed)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组创建时间。
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="egressPermissions")
    def egress_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupEgressPermissionArgs']]]]:
        return pulumi.get(self, "egress_permissions")

    @egress_permissions.setter
    def egress_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupEgressPermissionArgs']]]]):
        pulumi.set(self, "egress_permissions", value)

    @property
    @pulumi.getter(name="ingressPermissions")
    def ingress_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupIngressPermissionArgs']]]]:
        return pulumi.get(self, "ingress_permissions")

    @ingress_permissions.setter
    def ingress_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupIngressPermissionArgs']]]]):
        pulumi.set(self, "ingress_permissions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组所属项目名称。不填默认项目为default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组ID。
        """
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_group_id", value)

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        """
        return pulumi.get(self, "security_group_name")

    @security_group_name.setter
    def security_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_group_name", value)

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        安全组是否为托管安全组。true为托管安全组，false为非托管安全组。
        """
        return pulumi.get(self, "service_managed")

    @service_managed.setter
    def service_managed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "service_managed", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组状态。Available为可用，Creating为创建中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组类型。1、default：默认安全组。2、normal：自定义安全组。3、VpnGW： VPN网关安全组。4、NatGW： Nat网关安全组。 5、cidr_only：CIDR-Only安全组。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:vpc/securityGroup:SecurityGroup")
class SecurityGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupEgressPermissionArgs', 'SecurityGroupEgressPermissionArgsDict']]]]] = None,
                 ingress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupIngressPermissionArgs', 'SecurityGroupIngressPermissionArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupTagArgs', 'SecurityGroupTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        安全组是一个逻辑意义上的分组，为同一个私有网络内具有相同安全保护需求并相互信任的网卡提供访问策略。您可以通过配置安全组规则，控制安全组关联网卡的出入流量。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/securityGroup:SecurityGroup example "security_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        :param pulumi.Input[builtins.str] project_name: 安全组所属项目名称。不填默认项目为default。
        :param pulumi.Input[builtins.str] security_group_name: 安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        :param pulumi.Input[builtins.str] vpc_id: 安全组所属的VPC ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecurityGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        安全组是一个逻辑意义上的分组，为同一个私有网络内具有相同安全保护需求并相互信任的网卡提供访问策略。您可以通过配置安全组规则，控制安全组关联网卡的出入流量。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/securityGroup:SecurityGroup example "security_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param SecurityGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupEgressPermissionArgs', 'SecurityGroupEgressPermissionArgsDict']]]]] = None,
                 ingress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupIngressPermissionArgs', 'SecurityGroupIngressPermissionArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupTagArgs', 'SecurityGroupTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityGroupArgs.__new__(SecurityGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["egress_permissions"] = egress_permissions
            __props__.__dict__["ingress_permissions"] = ingress_permissions
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["security_group_name"] = security_group_name
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["security_group_id"] = None
            __props__.__dict__["service_managed"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
        super(SecurityGroup, __self__).__init__(
            'bytepluscc:vpc/securityGroup:SecurityGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            creation_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            egress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupEgressPermissionArgs', 'SecurityGroupEgressPermissionArgsDict']]]]] = None,
            ingress_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupIngressPermissionArgs', 'SecurityGroupIngressPermissionArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            security_group_id: Optional[pulumi.Input[builtins.str]] = None,
            security_group_name: Optional[pulumi.Input[builtins.str]] = None,
            service_managed: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGroupTagArgs', 'SecurityGroupTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'SecurityGroup':
        """
        Get an existing SecurityGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] creation_time: 安全组创建时间。
        :param pulumi.Input[builtins.str] description: 安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        :param pulumi.Input[builtins.str] project_name: 安全组所属项目名称。不填默认项目为default。
        :param pulumi.Input[builtins.str] security_group_id: 安全组ID。
        :param pulumi.Input[builtins.str] security_group_name: 安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        :param pulumi.Input[builtins.bool] service_managed: 安全组是否为托管安全组。true为托管安全组，false为非托管安全组。
        :param pulumi.Input[builtins.str] status: 安全组状态。Available为可用，Creating为创建中。
        :param pulumi.Input[builtins.str] type: 安全组类型。1、default：默认安全组。2、normal：自定义安全组。3、VpnGW： VPN网关安全组。4、NatGW： Nat网关安全组。 5、cidr_only：CIDR-Only安全组。
        :param pulumi.Input[builtins.str] vpc_id: 安全组所属的VPC ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityGroupState.__new__(_SecurityGroupState)

        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["description"] = description
        __props__.__dict__["egress_permissions"] = egress_permissions
        __props__.__dict__["ingress_permissions"] = ingress_permissions
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["security_group_id"] = security_group_id
        __props__.__dict__["security_group_name"] = security_group_name
        __props__.__dict__["service_managed"] = service_managed
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["vpc_id"] = vpc_id
        return SecurityGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[builtins.str]:
        """
        安全组创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        安全组的描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="egressPermissions")
    def egress_permissions(self) -> pulumi.Output[Sequence['outputs.SecurityGroupEgressPermission']]:
        return pulumi.get(self, "egress_permissions")

    @property
    @pulumi.getter(name="ingressPermissions")
    def ingress_permissions(self) -> pulumi.Output[Sequence['outputs.SecurityGroupIngressPermission']]:
        return pulumi.get(self, "ingress_permissions")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        安全组所属项目名称。不填默认项目为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> pulumi.Output[builtins.str]:
        """
        安全组ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> pulumi.Output[builtins.str]:
        """
        安全组的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认是安全组的ID。
        """
        return pulumi.get(self, "security_group_name")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> pulumi.Output[builtins.bool]:
        """
        安全组是否为托管安全组。true为托管安全组，false为非托管安全组。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        安全组状态。Available为可用，Creating为创建中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.SecurityGroupTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        安全组类型。1、default：默认安全组。2、normal：自定义安全组。3、VpnGW： VPN网关安全组。4、NatGW： Nat网关安全组。 5、cidr_only：CIDR-Only安全组。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        安全组所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

